@@ -19,12 +19,12 @@ from pathlib import Path
 from gvm.protocols.gmp import Gmp
 from lxml import etree
 
-__version__ = "24.12.0"
+__version__ = "21.7.1"
 
 logger = logging.getLogger(__name__)
 
 HELP_TEXT = f"""
-    Check-GMP Nagios Command Plugin for GOS 24.10 and newer
+    Check-GMP Nagios Command Plugin for GOS 22.04 and older
     Version {__version__} (C) 2017-2024 Greenbone AG
 
     This program is free software: you can redistribute it and/or modify
@@ -676,14 +676,13 @@ def filter_report(im, report, script_args):
     results = results[0]
     # Init variables
     any_found = False
-    critical_count = 0
     high_count = 0
     medium_count = 0
     low_count = 0
     log_count = 0
     error_count = 0
 
-    nvts = {"critical": [], "high": [], "medium": [], "low": [], "log": []}
+    nvts = {"high": [], "medium": [], "low": [], "log": []}
 
     all_results = results.xpath("result")
 
@@ -710,11 +709,7 @@ def filter_report(im, report, script_args):
             )
 
         threat = threat[0]
-        if threat in "Critical":
-            critical_count += 1
-            if script_args.oid:
-                nvts["critical"].append(retrieve_nvt_data(result))
-        elif threat in "High":
+        if threat in "High":
             high_count += 1
             if script_args.oid:
                 nvts["high"].append(retrieve_nvt_data(result))
@@ -750,7 +745,7 @@ def filter_report(im, report, script_args):
             error_count = errors.xpath("count/text()")[0]
 
     ret = 0
-    if critical_count + high_count > 0:
+    if high_count > 0:
         ret = NAGIOS_CRITICAL
     elif medium_count > 0:
         ret = NAGIOS_WARNING
@@ -762,9 +757,8 @@ def filter_report(im, report, script_args):
 
     print(
         f"GMP {NAGIOS_MSG[ret]}: "
-        f"{str((critical_count + high_count + medium_count + low_count))} "
-        f"vulnerabilities found - "
-        f"Critical: {str(critical_count)} High: {str(high_count)} "
+        f"{str((high_count + medium_count + low_count))} "
+        f"vulnerabilities found - High: {str(high_count)} "
         f"Medium: {str(medium_count)} Low: {str(low_count)}"
     )
 
@@ -816,8 +810,7 @@ def filter_report(im, report, script_args):
 
     end_session(
         im,
-        f"|Critical={str(critical_count)} "
-        f"High={str(high_count)} "
+        f"|High={str(high_count)} "
         f"Medium={str(medium_count)} "
         f"Low={str(low_count)}",
         ret,
